AutoArchive._services.external_command_executor.external_command_executor_service_identification — AutoArchive Developer Manual (ver. 2.0.6)

# Source code for AutoArchive._services.external_command_executor.external_command_executor_service_identification

    # external_command_executor_service_identification.py
    #
    # Project: AutoArchive
    # License: GNU GPLv3
    #
    # Copyright (C) 2003 - 2023 Róbert Čerňanský

    """:class:`ExternalCommandExecutorServiceIdentification` class."""

    __all__ = ["ExternalCommandExecutorServiceIdentification"]

    from AutoArchive._infrastructure.py_additions import staticproperty
    from AutoArchive._infrastructure.service import IServiceIdentification
    from ._external_command_executor import ExternalCommandExecutor

    class ExternalCommandExecutorServiceIdentification(IServiceIdentification):
        """Identifies External Command Executor service."""

        @staticproperty
        def interface() -> type[ExternalCommandExecutor]:
            """Gets interface type of the External Command Executor service.

            :rtype: ``type{``ExternalCommandExecutor``\ ``}``"""

            return ExternalCommandExecutor